@@ -1,5 +1,4 @@
 #Gnonlin-plugin isn't yet in maemos repository, so we compile it.
-#This will compile it for n810 with sb2.
 
 #file gnl/.libs/libgnl.so
 #should say: gnl/.libs/libgnl.so: ELF 32-bit LSB shared object, ARM, version 1 (SYSV), not stripped
@@ -10,8 +9,8 @@
 #gst-inspect gnonlin
 
 
-#If you can't compile it, precompiled version is on pre_compiled_plugin.
+#If you can't compile it, there are precompiled version on pre_compiled_plugin.
 #-Aapo Rantalainen
 
 cd gnonlin
-sb2 -e make
+make
