@@ -21,6 +21,12 @@ If it is global we can't use same behaviour in two different buttons.
  And creating new object-actor doesn't work.
 */
 
+#include <math.h>
+gdouble  my_sine_wave (ClutterAlpha *alpha,gpointer user_data) {
+
+return sin (clutter_timeline_get_progress (clutter_alpha_get_timeline (alpha)) * G_PI);
+}
+
 /**
  * config_return_script() returns a ClutterScript from the
  * parameter file given. Function returns NULL value if an
