@@ -31,16 +31,18 @@ moves too fast and isn't anymore top of object.
 */
 //void mouse_motion_on_stage(ClutterActor *actor, ClutterEvent *event, gpointer data) {
 void motion_on_object(ClutterActor *actor, ClutterEvent *event, gpointer data) {
-  gint x_mouse_position, y_mouse_position;
+  gfloat x_mouse_position_f, y_mouse_position_f;
 /*
 clutter_event_get_coords (event,&x_mouse_position, &y_mouse_position);
 clutter_actor_set_position (CLUTTER_ACTOR(actor), x_mouse_position, y_mouse_position);
 return;
 */
   if (CLUTTER_IS_ACTOR(dragging) && dragging != NULL) {
-      clutter_event_get_coords (event,&x_mouse_position, &y_mouse_position);
-      //printf("X=%d, Y=%d\n",x_mouse_position, y_mouse_position);
+      clutter_event_get_coords (event,&x_mouse_position_f, &y_mouse_position_f);
+      //printf("X=%f, Y=%f\n",x_mouse_position, y_mouse_position);
       gint new_x, new_y;
+      gint x_mouse_position=(gint)x_mouse_position_f;
+      gint y_mouse_position=(gint)y_mouse_position_f;
 
       //If object are over valid_area, use SNAPPING.
       if (is_inside_valid_area(x_mouse_position, y_mouse_position)) {
@@ -97,8 +99,9 @@ int i,j;
   GList *l;
   for (l = children; l; l = l->next){
     JammoTexture *actor = l->data;
-       gint x0,y0; //objects coordinates
-       clutter_actor_get_position (CLUTTER_ACTOR(actor),&x0,&y0);
+       gfloat x0_f,y0_f;
+       clutter_actor_get_position (CLUTTER_ACTOR(actor),&x0_f,&y0_f);
+       gint x0=(gint)x0_f,y0=(gint)y0_f; //objects coordinates
        //we are interested in only objects in valid_area (but not current_actor)
        if (is_inside_valid_area(x0,y0) && actor != dropped_actor){
              //printf("x=%d, y=%d\n",x0,y0);
@@ -155,7 +158,7 @@ put_in_timeline(dropped_actor,icon_place_of_dropped);
 	ClutterAlpha* alpha=clutter_behaviour_get_alpha(ab->behaviour);
 	ClutterTimeline *tl=clutter_alpha_get_timeline (alpha);
 
-	clutter_timeline_add_marker_at_frame (tl,"first_frame",1);
+//	clutter_timeline_add_marker_at_frame (tl,"first_frame",1);
 	g_signal_connect (tl, "marker-reached", G_CALLBACK (start_of_loop),ab);
 
 	//some mysterious reason, we can't remove first entry from list
@@ -207,10 +210,15 @@ return r;
 
 
 static void object_pressed (JammoTexture *actor, ClutterEvent *event, gpointer data) {
-  clutter_event_get_coords (event, &x_start_of_dragging, &y_start_of_dragging);
+  gfloat x_start_of_dragging_f,y_start_of_dragging_f;
+  clutter_event_get_coords (event, &x_start_of_dragging_f, &y_start_of_dragging_f);
+
+  x_start_of_dragging=(gint)x_start_of_dragging_f;
+  y_start_of_dragging=(gint)y_start_of_dragging_f;
+
   dragging=actor;// puts the actor clicked to the dragging actor
-  x_drag_offset = (clutter_actor_get_x (CLUTTER_ACTOR(dragging)) - x_start_of_dragging);
-  y_drag_offset = (clutter_actor_get_y (CLUTTER_ACTOR(dragging)) - y_start_of_dragging);
+  x_drag_offset = (clutter_actor_get_x (CLUTTER_ACTOR(dragging)) - (int)x_start_of_dragging);
+  y_drag_offset = (clutter_actor_get_y (CLUTTER_ACTOR(dragging)) - (int)y_start_of_dragging);
 
   //even this object is not focused it still gets the mouse events
   clutter_grab_pointer(CLUTTER_ACTOR(actor)); 
@@ -227,8 +235,10 @@ static void object_released (JammoTexture *actor, ClutterEvent *event, gpointer
     return;
   }
   //If object are clicked but not moved, we play its sound
-  gint x_release, y_release;
-  clutter_event_get_coords (event, &x_release, &y_release);
+  gfloat x_release_f, y_release_f;
+  clutter_event_get_coords (event, &x_release_f, &y_release_f);
+  gint x_release=(gint)x_release_f;
+  gint y_release=(gint)y_release_f;
   clutter_ungrab_pointer(); //ungrab
   dragging = NULL;
 
