@@ -182,7 +182,7 @@ void create_new_singing_track(void)
 	gchar converterA_nbr[15];
 	GstElement *encoder;
 
-	source = gst_element_factory_make("alsasrc", NULL);
+	source = gst_element_factory_make("autoaudiosrc", NULL);
 	sprintf(converterA_nbr, "converterA_%d", track_number);
 	audioconvertA = gst_element_factory_make("audioconvert", converterA_nbr);
 	encoder = gst_element_factory_make("wavenc", NULL);
